==> jasmine-expect-3.6.0.jar: META-INF/resources/webjars/jasmine-expect/3.6.0/CHANGELOG.md <==
<a name="3.6.0"></a>
# [3.6.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.5.0...v3.6.0) (2017-01-31)


### Features

* **objects:** add toHaveUndefined matcher ([443dc76](https://github.com/JamieMason/Jasmine-Matchers/commit/443dc76)), closes [#37](https://github.com/JamieMason/Jasmine-Matchers/issues/37)



<a name="3.5.0"></a>
# [3.5.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.2.0...3.5.0) (2017-01-18)


### Features

* **dates:** add toBeValidDate matcher ([47691cf](https://github.com/JamieMason/Jasmine-Matchers/commit/47691cf)), closes [#49](https://github.com/JamieMason/Jasmine-Matchers/issues/49)
* **jest:** add compatibility with jest ([0654bcc](https://github.com/JamieMason/Jasmine-Matchers/commit/0654bcc))
* **numbers:** add toBeNear matcher ([ffac1f5](https://github.com/JamieMason/Jasmine-Matchers/commit/ffac1f5)), closes [#58](https://github.com/JamieMason/Jasmine-Matchers/issues/58)



<a name="3.2.0"></a>
# [3.2.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.0.1...3.2.0) (2017-01-14)


### Features

* **regexps:** add any.regExp() ([a5079f8](https://github.com/JamieMason/Jasmine-Matchers/commit/a5079f8)), closes [#65](https://github.com/JamieMason/Jasmine-Matchers/issues/65)
* **regexps:** add toBeRegExp matcher ([c983e3c](https://github.com/JamieMason/Jasmine-Matchers/commit/c983e3c)), closes [#25](https://github.com/JamieMason/Jasmine-Matchers/issues/25) [#64](https://github.com/JamieMason/Jasmine-Matchers/issues/64)



<a name="3.0.1"></a>
## [3.0.1](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.2...3.0.1) (2016-08-23)


* feat(objects) deprecate .toImplement ([0f44ce5](https://github.com/JamieMason/Jasmine-Matchers/commit/0f44ce5))


### Bug Fixes

* **functions:** add android 4.0 support in toBeFunction ([1068001](https://github.com/JamieMason/Jasmine-Matchers/commit/1068001))


### Features

* **asymmetric:** add asymmetric matchers ([7cc229b](https://github.com/JamieMason/Jasmine-Matchers/commit/7cc229b))
* **numbers:** add toBeGreaterThanOrEqualTo ([ac5da2a](https://github.com/JamieMason/Jasmine-Matchers/commit/ac5da2a))
* **numbers:** add toBeLessThanOrEqualTo ([c5bc875](https://github.com/JamieMason/Jasmine-Matchers/commit/c5bc875))


### BREAKING CHANGES

* expect(object).toImplement has been deprecated, it is recommended to use jasmine.objectContaining() instead.



<a name="2.0.2"></a>
## [2.0.2](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.1...2.0.2) (2016-02-16)



<a name="2.0.1"></a>
## [2.0.1](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0...2.0.1) (2016-02-04)



<a name="2.0.0"></a>
# [2.0.0](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta5...2.0.0) (2016-02-03)



<a name="2.0.0-beta5"></a>
# [2.0.0-beta5](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta4...2.0.0-beta5) (2016-02-02)



<a name="2.0.0-beta4"></a>
# [2.0.0-beta4](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta3...2.0.0-beta4) (2016-02-01)



<a name="2.0.0-beta3"></a>
# [2.0.0-beta3](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta2...2.0.0-beta3) (2016-01-31)



<a name="2.0.0-beta2"></a>
# [2.0.0-beta2](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta1...2.0.0-beta2) (2015-09-13)



<a name="2.0.0-beta1"></a>
# [2.0.0-beta1](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.3...2.0.0-beta1) (2015-02-23)



<a name="1.22.3"></a>
## [1.22.3](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.2...1.22.3) (2014-12-31)



<a name="1.22.2"></a>
## [1.22.2](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.0...1.22.2) (2014-09-04)



<a name="1.22.0"></a>
# [1.22.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.20.0...1.22.0) (2014-07-25)



<a name="1.20.0"></a>
# [1.20.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.17.0...1.20.0) (2013-07-08)



<a name="1.17.0"></a>
# [1.17.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.4...1.17.0) (2013-07-04)



<a name="1.16.4"></a>
## [1.16.4](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.3...1.16.4) (2013-07-03)



<a name="1.16.3"></a>
## [1.16.3](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.1...1.16.3) (2013-07-03)



<a name="1.16.1"></a>
## 1.16.1 (2013-07-03)

==> jasmine-expect-3.8.3.jar: META-INF/resources/webjars/jasmine-expect/3.8.3/CHANGELOG.md <==
<a name="3.8.3"></a>
## [3.8.3](https://github.com/JamieMason/Jasmine-Matchers/compare/3.8.1...3.8.3) (2018-01-29)


### Bug Fixes

* **types:** update typescript definitions ([23ee7d8](https://github.com/JamieMason/Jasmine-Matchers/commit/23ee7d8))
* **typescript:** fix jest typings mismatch ([3cb9571](https://github.com/JamieMason/Jasmine-Matchers/commit/3cb9571)), closes [#62](https://github.com/JamieMason/Jasmine-Matchers/issues/62)



<a name="3.8.1"></a>
## [3.8.1](https://github.com/JamieMason/Jasmine-Matchers/compare/3.7.1...3.8.1) (2017-10-30)


### Features

* **core:** add typescript declarations for typing ([105bcc3](https://github.com/JamieMason/Jasmine-Matchers/commit/105bcc3))



<a name="3.7.1"></a>
## [3.7.1](https://github.com/JamieMason/Jasmine-Matchers/compare/3.7.0...3.7.1) (2017-07-27)


### Bug Fixes

* **npm:** update dependencies ([1b02c06](https://github.com/JamieMason/Jasmine-Matchers/commit/1b02c06))



<a name="3.7.0"></a>
# [3.7.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.6.0...3.7.0) (2017-03-10)



<a name="3.6.0"></a>
# [3.6.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.5.0...3.6.0) (2017-01-31)


### Features

* **objects:** add toHaveUndefined matcher ([443dc76](https://github.com/JamieMason/Jasmine-Matchers/commit/443dc76)), closes [#37](https://github.com/JamieMason/Jasmine-Matchers/issues/37)



<a name="3.5.0"></a>
# [3.5.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.2.0...3.5.0) (2017-01-18)


### Features

* **dates:** add toBeValidDate matcher ([47691cf](https://github.com/JamieMason/Jasmine-Matchers/commit/47691cf)), closes [#49](https://github.com/JamieMason/Jasmine-Matchers/issues/49)
* **jest:** add compatibility with jest ([0654bcc](https://github.com/JamieMason/Jasmine-Matchers/commit/0654bcc))
* **numbers:** add toBeNear matcher ([ffac1f5](https://github.com/JamieMason/Jasmine-Matchers/commit/ffac1f5)), closes [#58](https://github.com/JamieMason/Jasmine-Matchers/issues/58)



<a name="3.2.0"></a>
# [3.2.0](https://github.com/JamieMason/Jasmine-Matchers/compare/3.0.1...3.2.0) (2017-01-14)


### Features

* **regexps:** add any.regExp() ([a5079f8](https://github.com/JamieMason/Jasmine-Matchers/commit/a5079f8)), closes [#65](https://github.com/JamieMason/Jasmine-Matchers/issues/65)
* **regexps:** add toBeRegExp matcher ([c983e3c](https://github.com/JamieMason/Jasmine-Matchers/commit/c983e3c)), closes [#25](https://github.com/JamieMason/Jasmine-Matchers/issues/25) [#64](https://github.com/JamieMason/Jasmine-Matchers/issues/64)



<a name="3.0.1"></a>
## [3.0.1](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.2...3.0.1) (2016-08-23)


* feat(objects) deprecate .toImplement ([0f44ce5](https://github.com/JamieMason/Jasmine-Matchers/commit/0f44ce5))


### Bug Fixes

* **functions:** add android 4.0 support in toBeFunction ([1068001](https://github.com/JamieMason/Jasmine-Matchers/commit/1068001))


### Features

* **asymmetric:** add asymmetric matchers ([7cc229b](https://github.com/JamieMason/Jasmine-Matchers/commit/7cc229b))
* **numbers:** add toBeGreaterThanOrEqualTo ([ac5da2a](https://github.com/JamieMason/Jasmine-Matchers/commit/ac5da2a))
* **numbers:** add toBeLessThanOrEqualTo ([c5bc875](https://github.com/JamieMason/Jasmine-Matchers/commit/c5bc875))


### BREAKING CHANGES

* expect(object).toImplement has been deprecated, it is recommended to use jasmine.objectContaining() instead.



<a name="2.0.2"></a>
## [2.0.2](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.1...2.0.2) (2016-02-16)



<a name="2.0.1"></a>
## [2.0.1](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0...2.0.1) (2016-02-04)



<a name="2.0.0"></a>
# [2.0.0](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta5...2.0.0) (2016-02-03)



<a name="2.0.0-beta5"></a>
# [2.0.0-beta5](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta4...2.0.0-beta5) (2016-02-02)



<a name="2.0.0-beta4"></a>
# [2.0.0-beta4](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta3...2.0.0-beta4) (2016-02-01)



<a name="2.0.0-beta3"></a>
# [2.0.0-beta3](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta2...2.0.0-beta3) (2016-01-31)



<a name="2.0.0-beta2"></a>
# [2.0.0-beta2](https://github.com/JamieMason/Jasmine-Matchers/compare/2.0.0-beta1...2.0.0-beta2) (2015-09-13)



<a name="2.0.0-beta1"></a>
# [2.0.0-beta1](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.3...2.0.0-beta1) (2015-02-23)



<a name="1.22.3"></a>
## [1.22.3](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.2...1.22.3) (2014-12-31)



<a name="1.22.2"></a>
## [1.22.2](https://github.com/JamieMason/Jasmine-Matchers/compare/1.22.0...1.22.2) (2014-09-04)



<a name="1.22.0"></a>
# [1.22.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.20.0...1.22.0) (2014-07-25)



<a name="1.20.0"></a>
# [1.20.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.17.0...1.20.0) (2013-07-08)



<a name="1.17.0"></a>
# [1.17.0](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.4...1.17.0) (2013-07-04)



<a name="1.16.4"></a>
## [1.16.4](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.3...1.16.4) (2013-07-03)



<a name="1.16.3"></a>
## [1.16.3](https://github.com/JamieMason/Jasmine-Matchers/compare/1.16.1...1.16.3) (2013-07-03)



<a name="1.16.1"></a>
## 1.16.1 (2013-07-03)
